==> Tegra_Multimedia_API_R24.2.1_aarch64.tbz2: tegra_multimedia_api/argus/apps/camera/docs/doxygen/html/search/all_74.js <==
var searchData=
[
  ['task_5fstart',['TASK_START',['../namespaceArgusSamples.html#a0f7c0a0ae52848a5bea395ccc41f69aea8d763dac4ccff5d85671d793b992adc4',1,'ArgusSamples']]],
  ['taskgallery',['TaskGallery',['../classArgusSamples_1_1TaskGallery.html',1,'ArgusSamples']]],
  ['taskgallery',['TaskGallery',['../classArgusSamples_1_1TaskGallery.html#aac353c627a932e20a15637b878569d72',1,'ArgusSamples::TaskGallery']]],
  ['taskmultiexposure',['TaskMultiExposure',['../classArgusSamples_1_1TaskMultiExposure.html',1,'ArgusSamples']]],
  ['taskmultiexposure',['TaskMultiExposure',['../classArgusSamples_1_1TaskMultiExposure.html#a908ce0135a570955d90fa1b301e220fb',1,'ArgusSamples::TaskMultiExposure']]],
  ['taskmultisession',['TaskMultiSession',['../classArgusSamples_1_1TaskMultiSession.html#a360402fe92889c722c70bc220b976fc6',1,'ArgusSamples::TaskMultiSession']]],
  ['taskmultisession',['TaskMultiSession',['../classArgusSamples_1_1TaskMultiSession.html',1,'ArgusSamples']]],
  ['taskstillcapture',['TaskStillCapture',['../classArgusSamples_1_1TaskStillCapture.html',1,'ArgusSamples']]],
  ['taskstillcapture',['TaskStillCapture',['../classArgusSamples_1_1TaskStillCapture.html#a76b4bb0a3b7597c8bc801a3b3ac1bd97',1,'ArgusSamples::TaskStillCapture']]],
  ['taskvideorecord',['TaskVideoRecord',['../classArgusSamples_1_1TaskVideoRecord.html',1,'ArgusSamples']]],
  ['taskvideorecord',['TaskVideoRecord',['../classArgusSamples_1_1TaskVideoRecord.html#aac1b183a6af7d47800988de1f3746cac',1,'ArgusSamples::TaskVideoRecord']]],
  ['threadexecute',['threadExecute',['../classArgusSamples_1_1EventThread.html#ae6815a4aa478333976c608cec5cfbe6f',1,'ArgusSamples::EventThread::threadExecute()'],['../classArgusSamples_1_1GalleryThread.html#a1446f604f7ebd0f4b8007615c1cc37c5',1,'ArgusSamples::GalleryThread::threadExecute()'],['../classArgusSamples_1_1Composer.html#ac59c900b72da84a9e90f72a6b2d7f8e4',1,'ArgusSamples::Composer::threadExecute()'],['../classArgusSamples_1_1StreamConsumer.html#a6143d3da526b9c474eac3b0e13d48ecb',1,'ArgusSamples::StreamConsumer::threadExecute()']]],
  ['threadinitialize',['threadInitialize',['../classArgusSamples_1_1EventThread.html#a1ca2fcbe920c3c5ee7802fe92352a512',1,'ArgusSamples::EventThread::threadInitialize()'],['../classArgusSamples_1_1GalleryThread.html#a48ab0860cfc6fb0ed83c92343583d5be',1,'ArgusSamples::GalleryThread::threadInitialize()'],['../classArgusSamples_1_1Composer.html#a18a108f1f95d8f07a43f578d4934f03d',1,'ArgusSamples::Composer::threadInitialize()'],['../classArgusSamples_1_1StreamConsumer.html#a6dc51d8ed771d368ae3f7d5b03f9e5f5',1,'ArgusSamples::StreamConsumer::threadInitialize()']]],
  ['threadshutdown',['threadShutdown',['../classArgusSamples_1_1EventThread.html#ab638abeda6897a6154b6e6c0a495ac47',1,'ArgusSamples::EventThread::threadShutdown()'],['../classArgusSamples_1_1GalleryThread.html#abe95500abd87e88f74976622242fb7c0',1,'ArgusSamples::GalleryThread::threadShutdown()'],['../classArgusSamples_1_1Composer.html#aa8ce4888acda5bf8c5fe412d581f8061',1,'ArgusSamples::Composer::threadShutdown()'],['../classArgusSamples_1_1StreamConsumer.html#a670d221b64ea310624d0130d9de7af69',1,'ArgusSamples::StreamConsumer::threadShutdown()']]],
  ['timevalue',['TimeValue',['../classArgusSamples_1_1TimeValue.html',1,'ArgusSamples']]],
  ['timevalue',['TimeValue',['../classArgusSamples_1_1TimeValue.html#a1e32ff1527702a162d08de8aaffb6fe7',1,'ArgusSamples::TimeValue::TimeValue()'],['../classArgusSamples_1_1TimeValue.html#abb3d70c3c2e5ccd0bda30ebc0e2ed946',1,'ArgusSamples::TimeValue::TimeValue(NSecType value)']]],
  ['tocyclespersec',['toCyclesPerSec',['../classArgusSamples_1_1TimeValue.html#ae0908bd3be8111ff19bb05ca7e2ff7b8',1,'ArgusSamples::TimeValue']]],
  ['todo_20list',['Todo List',['../todo.html',1,'']]],
  ['toggle',['toggle',['../classArgusSamples_1_1VideoPipeline.html#a1533499b26cf33f84bf298ac752849d0',1,'ArgusSamples::VideoPipeline']]],
  ['toggleplayback',['togglePlayBack',['../classArgusSamples_1_1GalleryItem.html#a942a777c507ceb8660b0522f04adb4ab',1,'ArgusSamples::GalleryItem::togglePlayBack()'],['../classArgusSamples_1_1GalleryItemVideo.html#a9da8cac83de3d8f74c2c18d73a3cb40c',1,'ArgusSamples::GalleryItemVideo::togglePlayBack()'],['../classArgusSamples_1_1GalleryThread.html#a9c4be9815c4d62786cd3fcfce31e5c8b',1,'ArgusSamples::GalleryThread::togglePlayBack()'],['../classArgusSamples_1_1TaskGallery.html#a39ea1cc7dece34a69b708f7b85dad8eb',1,'ArgusSamples::TaskGallery::togglePlayBack()'],['../classArgusSamples_1_1AppModuleGallery.html#adeabf7923495c1899a2b0d9d756cf500',1,'ArgusSamples::AppModuleGallery::togglePlayBack()']]],
  ['togglerecording',['toggleRecording',['../classArgusSamples_1_1TaskVideoRecord.html#a96459f98102e91826def10d8ffeb767f',1,'ArgusSamples::TaskVideoRecord::toggleRecording()'],['../classArgusSamples_1_1AppModuleVideo.html#abca1250255406e50124741aaab73969d',1,'ArgusSamples::AppModuleVideo::toggleRecording()']]],
  ['tomsec',['toMSec',['../classArgusSamples_1_1TimeValue.html#a723641ec0e00d8cf2121d6158bc8c623',1,'ArgusSamples::TimeValue']]],
  ['tonsec',['toNSec',['../classArgusSamples_1_1TimeValue.html#a4ba6545e9809976c9b297777c18e0b27',1,'ArgusSamples::TimeValue']]],
  ['tosec',['toSec',['../classArgusSamples_1_1TimeValue.html#a94e9574505f47147b2214ef68f75d6f3',1,'ArgusSamples::TimeValue']]],
  ['tousec',['toUSec',['../classArgusSamples_1_1TimeValue.html#a59ae1d5687fd823923912a276838c032',1,'ArgusSamples::TimeValue']]],
  ['type',['Type',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087',1,'ArgusSamples::GalleryItem::Type()'],['../classArgusSamples_1_1Options_1_1Option.html#a26f8fb8eaf27c816566e15091ef376c1',1,'ArgusSamples::Options::Option::Type()']]],
  ['type_5faction',['TYPE_ACTION',['../classArgusSamples_1_1Options_1_1Option.html#a26f8fb8eaf27c816566e15091ef376c1ae1b59ceb7729f535cb6a093d5433e7ff',1,'ArgusSamples::Options::Option']]],
  ['type_5fimage',['TYPE_IMAGE',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087a3c56018385823873324e250ba649bddc',1,'ArgusSamples::GalleryItem']]],
  ['type_5finvalid',['TYPE_INVALID',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087a50c41f9c0e004e49a84da8129bf0b3a7',1,'ArgusSamples::GalleryItem']]],
  ['type_5foption',['TYPE_OPTION',['../classArgusSamples_1_1Options_1_1Option.html#a26f8fb8eaf27c816566e15091ef376c1a1e63ba61a4da289b6e619f8c5c70ed96',1,'ArgusSamples::Options::Option']]],
  ['type_5fvideo',['TYPE_VIDEO',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087aba2eba8ee8c4e249b7d6f6ded2c32eba',1,'ArgusSamples::GalleryItem']]]
];

==> Tegra_Multimedia_API_R27.1.0_aarch64.tbz2: tegra_multimedia_api/argus/apps/camera/docs/doxygen/html/search/all_74.js <==
var searchData=
[
  ['task_5fstart',['TASK_START',['../namespaceArgusSamples.html#a0f7c0a0ae52848a5bea395ccc41f69aea8d763dac4ccff5d85671d793b992adc4',1,'ArgusSamples']]],
  ['taskgallery',['TaskGallery',['../classArgusSamples_1_1TaskGallery.html',1,'ArgusSamples']]],
  ['taskgallery',['TaskGallery',['../classArgusSamples_1_1TaskGallery.html#aac353c627a932e20a15637b878569d72',1,'ArgusSamples::TaskGallery']]],
  ['taskmultiexposure',['TaskMultiExposure',['../classArgusSamples_1_1TaskMultiExposure.html',1,'ArgusSamples']]],
  ['taskmultiexposure',['TaskMultiExposure',['../classArgusSamples_1_1TaskMultiExposure.html#a908ce0135a570955d90fa1b301e220fb',1,'ArgusSamples::TaskMultiExposure']]],
  ['taskmultisession',['TaskMultiSession',['../classArgusSamples_1_1TaskMultiSession.html#a360402fe92889c722c70bc220b976fc6',1,'ArgusSamples::TaskMultiSession']]],
  ['taskmultisession',['TaskMultiSession',['../classArgusSamples_1_1TaskMultiSession.html',1,'ArgusSamples']]],
  ['taskstillcapture',['TaskStillCapture',['../classArgusSamples_1_1TaskStillCapture.html',1,'ArgusSamples']]],
  ['taskstillcapture',['TaskStillCapture',['../classArgusSamples_1_1TaskStillCapture.html#a76b4bb0a3b7597c8bc801a3b3ac1bd97',1,'ArgusSamples::TaskStillCapture']]],
  ['taskvideorecord',['TaskVideoRecord',['../classArgusSamples_1_1TaskVideoRecord.html#aac1b183a6af7d47800988de1f3746cac',1,'ArgusSamples::TaskVideoRecord']]],
  ['taskvideorecord',['TaskVideoRecord',['../classArgusSamples_1_1TaskVideoRecord.html',1,'ArgusSamples']]],
  ['threadexecute',['threadExecute',['../classArgusSamples_1_1EventThread.html#ae6815a4aa478333976c608cec5cfbe6f',1,'ArgusSamples::EventThread::threadExecute()'],['../classArgusSamples_1_1GalleryThread.html#a1446f604f7ebd0f4b8007615c1cc37c5',1,'ArgusSamples::GalleryThread::threadExecute()'],['../classArgusSamples_1_1Composer.html#ac59c900b72da84a9e90f72a6b2d7f8e4',1,'ArgusSamples::Composer::threadExecute()'],['../classArgusSamples_1_1StreamConsumer.html#a6143d3da526b9c474eac3b0e13d48ecb',1,'ArgusSamples::StreamConsumer::threadExecute()']]],
  ['threadinitialize',['threadInitialize',['../classArgusSamples_1_1EventThread.html#a1ca2fcbe920c3c5ee7802fe92352a512',1,'ArgusSamples::EventThread::threadInitialize()'],['../classArgusSamples_1_1GalleryThread.html#a48ab0860cfc6fb0ed83c92343583d5be',1,'ArgusSamples::GalleryThread::threadInitialize()'],['../classArgusSamples_1_1Composer.html#a18a108f1f95d8f07a43f578d4934f03d',1,'ArgusSamples::Composer::threadInitialize()'],['../classArgusSamples_1_1StreamConsumer.html#a6dc51d8ed771d368ae3f7d5b03f9e5f5',1,'ArgusSamples::StreamConsumer::threadInitialize()']]],
  ['threadshutdown',['threadShutdown',['../classArgusSamples_1_1EventThread.html#ab638abeda6897a6154b6e6c0a495ac47',1,'ArgusSamples::EventThread::threadShutdown()'],['../classArgusSamples_1_1GalleryThread.html#abe95500abd87e88f74976622242fb7c0',1,'ArgusSamples::GalleryThread::threadShutdown()'],['../classArgusSamples_1_1Composer.html#aa8ce4888acda5bf8c5fe412d581f8061',1,'ArgusSamples::Composer::threadShutdown()'],['../classArgusSamples_1_1StreamConsumer.html#a670d221b64ea310624d0130d9de7af69',1,'ArgusSamples::StreamConsumer::threadShutdown()']]],
  ['timevalue',['TimeValue',['../classArgusSamples_1_1TimeValue.html#a1e32ff1527702a162d08de8aaffb6fe7',1,'ArgusSamples::TimeValue::TimeValue()'],['../classArgusSamples_1_1TimeValue.html#abb3d70c3c2e5ccd0bda30ebc0e2ed946',1,'ArgusSamples::TimeValue::TimeValue(NSecType value)']]],
  ['timevalue',['TimeValue',['../classArgusSamples_1_1TimeValue.html',1,'ArgusSamples']]],
  ['tocyclespersec',['toCyclesPerSec',['../classArgusSamples_1_1TimeValue.html#ae0908bd3be8111ff19bb05ca7e2ff7b8',1,'ArgusSamples::TimeValue']]],
  ['todo_20list',['Todo List',['../todo.html',1,'']]],
  ['toggle',['toggle',['../classArgusSamples_1_1VideoPipeline.html#a1533499b26cf33f84bf298ac752849d0',1,'ArgusSamples::VideoPipeline']]],
  ['toggleplayback',['togglePlayBack',['../classArgusSamples_1_1GalleryItem.html#a942a777c507ceb8660b0522f04adb4ab',1,'ArgusSamples::GalleryItem::togglePlayBack()'],['../classArgusSamples_1_1GalleryItemVideo.html#a9da8cac83de3d8f74c2c18d73a3cb40c',1,'ArgusSamples::GalleryItemVideo::togglePlayBack()'],['../classArgusSamples_1_1GalleryThread.html#a9c4be9815c4d62786cd3fcfce31e5c8b',1,'ArgusSamples::GalleryThread::togglePlayBack()'],['../classArgusSamples_1_1TaskGallery.html#a39ea1cc7dece34a69b708f7b85dad8eb',1,'ArgusSamples::TaskGallery::togglePlayBack()'],['../classArgusSamples_1_1AppModuleGallery.html#adeabf7923495c1899a2b0d9d756cf500',1,'ArgusSamples::AppModuleGallery::togglePlayBack()']]],
  ['togglerecording',['toggleRecording',['../classArgusSamples_1_1TaskVideoRecord.html#a96459f98102e91826def10d8ffeb767f',1,'ArgusSamples::TaskVideoRecord::toggleRecording()'],['../classArgusSamples_1_1AppModuleVideo.html#abca1250255406e50124741aaab73969d',1,'ArgusSamples::AppModuleVideo::toggleRecording()']]],
  ['tomsec',['toMSec',['../classArgusSamples_1_1TimeValue.html#a723641ec0e00d8cf2121d6158bc8c623',1,'ArgusSamples::TimeValue']]],
  ['tonsec',['toNSec',['../classArgusSamples_1_1TimeValue.html#a4ba6545e9809976c9b297777c18e0b27',1,'ArgusSamples::TimeValue']]],
  ['tosec',['toSec',['../classArgusSamples_1_1TimeValue.html#a94e9574505f47147b2214ef68f75d6f3',1,'ArgusSamples::TimeValue']]],
  ['tousec',['toUSec',['../classArgusSamples_1_1TimeValue.html#a59ae1d5687fd823923912a276838c032',1,'ArgusSamples::TimeValue']]],
  ['track',['track',['../classArgusSamples_1_1Dispatcher.html#a6d32aac6ebe915a7b50fcec8722ad1d8',1,'ArgusSamples::Dispatcher::track(Argus::CaptureSession *session)'],['../classArgusSamples_1_1Dispatcher.html#ab4ce83bafd8a59a16ab1bb904810f3e1',1,'ArgusSamples::Dispatcher::track(Argus::Request *request)'],['../classArgusSamples_1_1Tracker.html#a114c7ca03b1075fc5c7a09d2d3e64487',1,'ArgusSamples::Tracker::track()']]],
  ['trackeduniqueobj',['TrackedUniqueObj',['../classArgusSamples_1_1TrackedUniqueObj.html#aee7fad1d6e1f77007e18ac04eb9fc005',1,'ArgusSamples::TrackedUniqueObj']]],
  ['trackeduniqueobj',['TrackedUniqueObj',['../classArgusSamples_1_1TrackedUniqueObj.html',1,'ArgusSamples']]],
  ['trackeduniqueobj_3c_20argus_3a_3acapturesession_20_3e',['TrackedUniqueObj&lt; Argus::CaptureSession &gt;',['../classArgusSamples_1_1TrackedUniqueObj.html',1,'ArgusSamples']]],
  ['trackeduniqueobj_3c_20argus_3a_3arequest_20_3e',['TrackedUniqueObj&lt; Argus::Request &gt;',['../classArgusSamples_1_1TrackedUniqueObj.html',1,'ArgusSamples']]],
  ['trackeduniqueobject_2eh',['TrackedUniqueObject.h',['../TrackedUniqueObject_8h.html',1,'']]],
  ['tracker',['Tracker',['../classArgusSamples_1_1Tracker.html',1,'ArgusSamples']]],
  ['tracker_3c_20argus_3a_3acapturesession_20_3e',['Tracker&lt; Argus::CaptureSession &gt;',['../classArgusSamples_1_1Tracker.html',1,'ArgusSamples']]],
  ['tracker_3c_20argus_3a_3arequest_20_3e',['Tracker&lt; Argus::Request &gt;',['../classArgusSamples_1_1Tracker.html',1,'ArgusSamples']]],
  ['tracker_3c_20t_20_3e',['Tracker&lt; T &gt;',['../classArgusSamples_1_1TrackedUniqueObj.html#ae0338ea06b831b6b6a8e17ad0081a062',1,'ArgusSamples::TrackedUniqueObj']]],
  ['type',['Type',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087',1,'ArgusSamples::GalleryItem']]],
  ['type_5fimage',['TYPE_IMAGE',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087a3c56018385823873324e250ba649bddc',1,'ArgusSamples::GalleryItem']]],
  ['type_5finvalid',['TYPE_INVALID',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087a50c41f9c0e004e49a84da8129bf0b3a7',1,'ArgusSamples::GalleryItem']]],
  ['type_5fvideo',['TYPE_VIDEO',['../classArgusSamples_1_1GalleryItem.html#a6bffae895927eb4b5331dd796018d087aba2eba8ee8c4e249b7d6f6ded2c32eba',1,'ArgusSamples::GalleryItem']]]
];
